/*--------------------------------------------------------------------------+
$Id$
|                                                                          |
| Copyright 2015 fortiss GmbH                     |
|                                                                          |
| Licensed under the Apache License, Version 2.0 (the "License");          |
| you may not use this file except in compliance with the License.         |
| You may obtain a copy of the License at                                  |
|                                                                          |
|    http://www.apache.org/licenses/LICENSE-2.0                            |
|                                                                          |
| Unless required by applicable law or agreed to in writing, software      |
| distributed under the License is distributed on an "AS IS" BASIS,        |
| WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. |
| See the License for the specific language governing permissions and      |
| limitations under the License.                                           |
+--------------------------------------------------------------------------*/
package org.fortiss.tooling.base.ui.editpart.allocation;

import static org.eclipse.gef.LayerConstants.CONNECTION_LAYER;

import org.eclipse.draw2d.BendpointConnectionRouter;
import org.eclipse.draw2d.ColorConstants;
import org.eclipse.draw2d.ConnectionAnchor;
import org.eclipse.draw2d.ConnectionLayer;
import org.eclipse.draw2d.ConnectionRouter;
import org.eclipse.draw2d.FreeformLayer;
import org.eclipse.draw2d.IFigure;
import org.eclipse.draw2d.XYLayout;
import org.eclipse.emf.ecore.EObject;
import org.eclipse.gef.ConnectionEditPart;
import org.eclipse.gef.EditPart;
import org.eclipse.gef.NodeEditPart;
import org.eclipse.gef.Request;
import org.eclipse.swt.SWT;
import org.fortiss.tooling.base.ui.editpart.GraphicalEditPartBase;
import org.fortiss.tooling.base.ui.layout.IDiagramLayoutConfiguration;
import org.fortiss.tooling.base.ui.layout.RectangleGridLayoutDiagramConfiguration;

/**
 * The base class for allocation diagrams.
 * 
 * @param <T>
 *            the type of the model element shown.
 * 
 * @author eder
 * @author $Author$
 * @version $Rev$
 * @ConQAT.Rating GREEN Hash: 73346CF5CBAC03B32C7B1DFDC30AADA2
 */
public abstract class AllocationDiagramEditPartBase<T extends EObject> extends
		GraphicalEditPartBase<T> implements NodeEditPart {

	/** Stores the diagram layout configuration. */
	protected final IDiagramLayoutConfiguration layoutConfiguration;

	/** Stores the connection router. */
	private final ConnectionRouter connectionRouter;

	/** Constructor. */
	protected AllocationDiagramEditPartBase(T modelElement) {
		super(modelElement);
		this.layoutConfiguration = RectangleGridLayoutDiagramConfiguration.INSTANCE;
		this.connectionRouter = new BendpointConnectionRouter();
	}

	/** {@inheritDoc} */
	@Override
	public ConnectionAnchor getSourceConnectionAnchor(ConnectionEditPart connection) {
		return null;
	}

	/** {@inheritDoc} */
	@Override
	public ConnectionAnchor getTargetConnectionAnchor(ConnectionEditPart connection) {
		return null;
	}

	/** {@inheritDoc} */
	@Override
	public ConnectionAnchor getSourceConnectionAnchor(Request request) {
		return null;
	}

	/** {@inheritDoc} */
	@Override
	public ConnectionAnchor getTargetConnectionAnchor(Request request) {
		return null;
	}

	/** {@inheritDoc} */
	@Override
	protected void createEditPolicies() {
		// do nothing
	}

	/** {@inheritDoc} */
	@Override
	protected void refreshVisuals() {
		if(!getFigure().hasFocus()) {
			return;
		}
		super.refreshVisuals();

		refreshSourceConnections();
		refreshTargetConnections();
		refreshChildren();

		for(Object o : getChildren()) {
			((EditPart)o).refresh();
		}

		for(Object editPart : getSourceConnections()) {
			((EditPart)editPart).refresh();
		}
		for(Object editPart : getTargetConnections()) {
			((EditPart)editPart).refresh();
		}
	}

	/** {@inheritDoc} */
	@Override
	public void setFocus(boolean value) {
		super.setFocus(value);
		if(value) {
			refreshVisuals();
		}
	}

	/** {@inheritDoc} */
	@Override
	public IDiagramLayoutConfiguration getLayoutConfiguration() {
		return layoutConfiguration;
	}

	/** {@inheritDoc} */
	@Override
	protected IFigure createFigure() {
		setConnectionRouter();

		FreeformLayer f = new FreeformLayer();
		f.setOpaque(false);
		f.setLayoutManager(new XYLayout());
		f.setBackgroundColor(ColorConstants.white);
		return f;
	}

	/** Sets anti-aliasing and the connection router on connection layer. */
	private void setConnectionRouter() {
		ConnectionLayer cLayer = (ConnectionLayer)getLayer(CONNECTION_LAYER);
		if(cLayer != null) {
			cLayer.setAntialias(SWT.ON);
			cLayer.setConnectionRouter(connectionRouter);
		}
	}
}
