/*--------------------------------------------------------------------------+
$Id$
|                                                                          |
| Copyright 2015 fortiss GmbH                     |
|                                                                          |
| Licensed under the Apache License, Version 2.0 (the "License");          |
| you may not use this file except in compliance with the License.         |
| You may obtain a copy of the License at                                  |
|                                                                          |
|    http://www.apache.org/licenses/LICENSE-2.0                            |
|                                                                          |
| Unless required by applicable law or agreed to in writing, software      |
| distributed under the License is distributed on an "AS IS" BASIS,        |
| WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. |
| See the License for the specific language governing permissions and      |
| limitations under the License.                                           |
+--------------------------------------------------------------------------*/
package org.fortiss.tooling.base.ui.editpart.allocation;

import org.eclipse.draw2d.geometry.Rectangle;
import org.fortiss.tooling.base.model.element.IConnector;
import org.fortiss.tooling.base.model.layout.ILayoutedModelElement;
import org.fortiss.tooling.base.ui.editpart.StickyConnectorEditPartBase;
import org.fortiss.tooling.kernel.model.INamedCommentedElement;

/**
 * Sticky Connector implementation for allocation editors.
 * 
 * @author eder
 * @author $Author$
 * @version $Rev$
 * @ConQAT.Rating GREEN Hash: C346D7E5B39C2BBB5D2F2EEA5291F1F2
 */
public abstract class AllocationStickyConnectorEditPartBase<T extends ILayoutedModelElement & IConnector & INamedCommentedElement>
		extends StickyConnectorEditPartBase<T> {

	/** Constructor. */
	protected AllocationStickyConnectorEditPartBase(T modelElement) {
		super(modelElement);
		determineBaseFigureBounds();
	}

	/** {@inheritDoc} */
	@Override
	protected Rectangle determineLabelFigureBounds() {
		// position label right of base figure
		Rectangle textBounds = labelFigure.getTextBounds();
		Rectangle baseBounds = baseFigure.getBounds();
		Rectangle parentBounds = baseFigure.getParent().getParent().getBounds();

		return new Rectangle(parentBounds.x + baseBounds.x + baseBounds.width, parentBounds.y +
				baseBounds.y, textBounds.width, baseBounds.height);
	}

	/** {@inheritDoc} */
	@Override
	protected void createEditPolicies() {
		// do nothing since ports must not be removed in the allocation editor
	}
}
