/*--------------------------------------------------------------------------+
$Id$
|                                                                          |
| Copyright 2015 fortiss GmbH                     |
|                                                                          |
| Licensed under the Apache License, Version 2.0 (the "License");          |
| you may not use this file except in compliance with the License.         |
| You may obtain a copy of the License at                                  |
|                                                                          |
|    http://www.apache.org/licenses/LICENSE-2.0                            |
|                                                                          |
| Unless required by applicable law or agreed to in writing, software      |
| distributed under the License is distributed on an "AS IS" BASIS,        |
| WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. |
| See the License for the specific language governing permissions and      |
| limitations under the License.                                           |
+--------------------------------------------------------------------------*/
package org.fortiss.tooling.base.ui.editpart.allocation;

import org.eclipse.draw2d.geometry.Point;
import org.eclipse.draw2d.geometry.Rectangle;
import org.eclipse.gef.RootEditPart;
import org.fortiss.tooling.base.ui.editpart.SubDiagramEditPartBase;

/**
 * Interface for allocation target elements.
 * Stores the position of allocation sources and allocation targets in the diagram editor. Connects
 * the position to the {@link SubDiagramEditPartBase}s and stores their bounds.
 * 
 * @author eder
 * @author $Author$
 * @version $Rev$
 * @ConQAT.Rating GREEN Hash: 7B380D0C1D3D99179068A8DD5FB581F0
 */
public interface IAllocationPositionService {
	/** Returns the service instance. */
	public static IAllocationPositionService getInstance() {
		return AllocationPositionService.getInstance();
	}

	/** Returns the top left most position of the source elements. */
	Point getMinSourcePos(RootEditPart root);

	/** Returns the top left most position of the target elements. */
	Point getMinTargetPos(RootEditPart root);

	/** Returns the bounds of the allocation source elements. */
	Rectangle getSourceAllocationBounds(RootEditPart root);

	/** Returns the bounds of the allocation target elements. */
	Rectangle getTargetAllocationBounds(RootEditPart root);

	/** Saves the top left most position of the source elements. */
	void setMinSourcePos(RootEditPart root, Point point);

	/** Saves the top left most position of the target elements. */
	void setMinTargetPos(RootEditPart root, Point point);

	/** Saves the bounds of the allocation source elements. */
	void setSourceAllocationBounds(RootEditPart root, Rectangle bounds);

	/** Saves the bounds of the allocation target elements. */
	void setTargetAllocationBounds(RootEditPart root, Rectangle bounds);
}
