/*--------------------------------------------------------------------------+
$Id$
|                                                                          |
| Copyright 2011 fortiss GmbH                     |
|                                                                          |
| Licensed under the Apache License, Version 2.0 (the "License");          |
| you may not use this file except in compliance with the License.         |
| You may obtain a copy of the License at                                  |
|                                                                          |
|    http://www.apache.org/licenses/LICENSE-2.0                            |
|                                                                          |
| Unless required by applicable law or agreed to in writing, software      |
| distributed under the License is distributed on an "AS IS" BASIS,        |
| WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. |
| See the License for the specific language governing permissions and      |
| limitations under the License.                                           |
+--------------------------------------------------------------------------*/
package org.fortiss.tooling.base.ui.fieldassist;

import org.eclipse.jface.bindings.keys.KeyStroke;

/**
 * Interface defining the {@link IProposalProvider} necessary to add custom
 * field assist to text widgets.
 * 
 * @author doebber
 * @author $Author$
 * @version $Rev$
 * @ConQAT.Rating GREEN Hash: 9A07D97EFF71B4A16684197C7E47D260
 */
public interface IProposalProvider {

	/**
	 * Returns the specific proposals. This method is called every time the
	 * assist window opens up. Implementors may generate and return dynamic
	 * proposals here.
	 */
	public String[] getProposals(String currentWord);

	/** The keystroke the field assist is activated for. */
	public KeyStroke getKeystroke();

	/**
	 * Array of chars the assist is activated for. A typical example in Java
	 * would be '.' as an auto activation char.
	 */
	public char[] getAutoActivationChars();

	/**
	 * Returns an array of chars other than 'space' that will be used to
	 * determine the beginning of the word to propose for. Typical examples
	 * might be '.', '=' or any operands.
	 */
	public char[] getAdditionalWhitespaceChars();
}
