/*--------------------------------------------------------------------------+
$Id$
|                                                                          |
| Copyright 2012 fortiss GmbH                     |
|                                                                          |
| Licensed under the Apache License, Version 2.0 (the "License");          |
| you may not use this file except in compliance with the License.         |
| You may obtain a copy of the License at                                  |
|                                                                          |
|    http://www.apache.org/licenses/LICENSE-2.0                            |
|                                                                          |
| Unless required by applicable law or agreed to in writing, software      |
| distributed under the License is distributed on an "AS IS" BASIS,        |
| WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. |
| See the License for the specific language governing permissions and      |
| limitations under the License.                                           |
+--------------------------------------------------------------------------*/
package org.fortiss.tooling.base.ui.fieldassist;

import org.eclipse.jface.bindings.keys.KeyStroke;
import org.eclipse.jface.bindings.keys.ParseException;

/**
 * Base implementation for {@link IProposalProvider}.
 * 
 * @author doebber
 * @author $Author$
 * @version $Rev$
 * @ConQAT.Rating GREEN Hash: 745689CC54C9DDEA65A4368A50318AEC
 */
public abstract class ProposalProviderBase implements IProposalProvider {

	/**
	 * Default keystroke for assist activation. Used if no other keystroke
	 * specified.
	 */
	public static final String DEFAULT_KEYSTROKE = "Ctrl+Space";

	/** {@inheritDoc} */
	@Override
	public KeyStroke getKeystroke() {
		KeyStroke key = null;
		try {
			key = KeyStroke.getInstance(DEFAULT_KEYSTROKE);
		} catch(ParseException e) {
			// Should not happen
			e.printStackTrace();
		}
		return key;
	}

	/** {@inheritDoc} */
	@Override
	public char[] getAutoActivationChars() {
		return null;
	}

	/** {@inheritDoc} */
	@Override
	public char[] getAdditionalWhitespaceChars() {
		return new char[] {'=', '<', '>', '+', '-', '*', '/', '%', '(', ')', '&', '|', ';', '!',
				','};
	}
}
