/*--------------------------------------------------------------------------+
$Id$
|                                                                          |
| Copyright 2012 fortiss GmbH                     |
|                                                                          |
| Licensed under the Apache License, Version 2.0 (the "License");          |
| you may not use this file except in compliance with the License.         |
| You may obtain a copy of the License at                                  |
|                                                                          |
|    http://www.apache.org/licenses/LICENSE-2.0                            |
|                                                                          |
| Unless required by applicable law or agreed to in writing, software      |
| distributed under the License is distributed on an "AS IS" BASIS,        |
| WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. |
| See the License for the specific language governing permissions and      |
| limitations under the License.                                           |
+--------------------------------------------------------------------------*/
package org.fortiss.tooling.base.ui.library;

import static org.fortiss.tooling.kernel.utils.EcoreUtils.pickInstanceOf;

import java.util.List;

import org.eclipse.emf.ecore.EObject;
import org.eclipse.jface.window.Window;
import org.eclipse.swt.widgets.Shell;
import org.eclipse.ui.PlatformUI;
import org.fortiss.tooling.base.ui.dialog.ElementTreeSingleSelectDialog;
import org.fortiss.tooling.base.ui.dialog.ModelElementTreeContentProvider;
import org.fortiss.tooling.kernel.model.ILibrary;
import org.fortiss.tooling.kernel.model.ILibraryPackage;
import org.fortiss.tooling.kernel.service.ILibraryService;
import org.fortiss.tooling.kernel.ui.presentation.ModelElementLabelProvider;

/**
 * Provides a dialog for selecting an library package.
 * 
 * @author ratiu
 * @author $Author$
 * @version $Rev$
 * @ConQAT.Rating GREEN Hash: 407CCDDCD552D468101A48DD0219A140
 */
public class LibrarySelectionDialog {

	/** Opens a dialog to select the library root. */
	@SuppressWarnings("unchecked")
	public static <T extends ILibraryPackage> T openLibraryPackageDialog(
			final Class<T> libraryPackageClass) {
		Shell shell = PlatformUI.getWorkbench().getActiveWorkbenchWindow().getShell();
		List<ILibrary> allLibs = ILibraryService.getInstance().getLibrariesFromWorkspace();

		ElementTreeSingleSelectDialog dialog =
				new ElementTreeSingleSelectDialog(shell, "Library package selection",
						"Please select a package where the element should be placed", allLibs,
						null, new ModelElementTreeContentProvider(allLibs) {

							/** {@inheritDoc} */
							@Override
							public List<? extends EObject> getChildren(EObject parent) {
								return pickInstanceOf(libraryPackageClass,
										super.getChildren(parent));
							}
						}, new ModelElementLabelProvider(), null) {

					/** {@inheritDoc} */
					@Override
					public boolean acceptElement(Object element) {
						return element instanceof ILibraryPackage;
					}
				};

		if(Window.OK == dialog.open()) {
			Object selectedElement = dialog.getSelectedElement();
			if(libraryPackageClass.isAssignableFrom(selectedElement.getClass())) {
				return (T)selectedElement;
			}
		}

		return null;
	}
}
