/*--------------------------------------------------------------------------+
$Id$
|                                                                          |
| Copyright 2011 fortiss GmbH                     |
|                                                                          |
| Licensed under the Apache License, Version 2.0 (the "License");          |
| you may not use this file except in compliance with the License.         |
| You may obtain a copy of the License at                                  |
|                                                                          |
|    http://www.apache.org/licenses/LICENSE-2.0                            |
|                                                                          |
| Unless required by applicable law or agreed to in writing, software      |
| distributed under the License is distributed on an "AS IS" BASIS,        |
| WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. |
| See the License for the specific language governing permissions and      |
| limitations under the License.                                           |
+--------------------------------------------------------------------------*/
package org.fortiss.tooling.base.ui.tablecell;

import org.eclipse.jface.viewers.CellEditor;
import org.eclipse.jface.viewers.CheckboxCellEditor;
import org.eclipse.jface.viewers.ColumnViewer;
import org.eclipse.jface.viewers.EditingSupport;

/**
 * {@link EditingSupport} for checkbox cells.
 * 
 * @author hoelzl
 * @author $Author$
 * @version $Rev$
 * @ConQAT.Rating YELLOW Hash: 2EC9E3CC10AF755346867DAECA167352
 */
public abstract class CheckBoxEditingSupport extends EditingSupport {

	/** Stores the shared cell editor. */
	private CellEditor cellEditor;

	/** Constructor */
	public CheckBoxEditingSupport(ColumnViewer viewer) {
		super(viewer);
		cellEditor = new CheckboxCellEditor(viewer.getControl().getParent());
	}

	/** {@inheritDoc} */
	@Override
	protected boolean canEdit(Object element) {
		return true;
	}

	/** {@inheritDoc} */
	@Override
	protected final CellEditor getCellEditor(Object element) {
		return cellEditor;
	}

	/** {@inheritDoc} */
	@Override
	protected final Object getValue(Object element) {
		return getBooleanValue(element);
	}

	/** Get the boolean value of this editor. */
	protected abstract Boolean getBooleanValue(Object element);

	/** {@inheritDoc} */
	@Override
	protected final void setValue(Object element, Object value) {
		if(value instanceof Boolean) {
			setBooleanValue(element, (Boolean)value);
			getViewer().update(element, null);
		}
	}

	/** Sets the boolean value to the model. */
	protected abstract void setBooleanValue(Object element, Boolean value);
}
