/*--------------------------------------------------------------------------+
$Id$
|                                                                          |
| Copyright 2011 fortiss GmbH                     |
|                                                                          |
| Licensed under the Apache License, Version 2.0 (the "License");          |
| you may not use this file except in compliance with the License.         |
| You may obtain a copy of the License at                                  |
|                                                                          |
|    http://www.apache.org/licenses/LICENSE-2.0                            |
|                                                                          |
| Unless required by applicable law or agreed to in writing, software      |
| distributed under the License is distributed on an "AS IS" BASIS,        |
| WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. |
| See the License for the specific language governing permissions and      |
| limitations under the License.                                           |
+--------------------------------------------------------------------------*/
package org.fortiss.tooling.base.ui.utils;

import static org.conqat.ide.commons.ui.ui.WorkbenchUtils.getActiveWorkbenchPage;

import org.eclipse.jface.action.IStatusLineManager;
import org.eclipse.ui.IActionBars;
import org.eclipse.ui.IViewSite;
import org.eclipse.ui.IWorkbenchPage;
import org.eclipse.ui.IWorkbenchPart;
import org.eclipse.ui.IWorkbenchPartSite;

/**
 * Methods for accessing the status line.
 * 
 * @author gareis
 * @author $Author$
 * @version $Rev$
 * @ConQAT.Rating GREEN Hash: E85DB1C82F0D19FF3569FE1B5CE19B69
 */
public class StatusUtils {

	/**
	 * Returns a Status Line object of the current window.
	 * 
	 * @return the status line manager
	 */
	public static IStatusLineManager getStatusLine() {
		IWorkbenchPage page = getActiveWorkbenchPage();
		IWorkbenchPart part = page.getActivePart();
		IWorkbenchPartSite site = part.getSite();
		IViewSite vSite = (IViewSite)site;
		IActionBars actionBars = vSite.getActionBars();

		if(actionBars == null) {
			return null;
		}

		IStatusLineManager statusLine = actionBars.getStatusLineManager();
		if(statusLine == null) {
			return null;
		}
		return statusLine;
	}

	/**
	 * Writes messages into the status line of the current window.
	 * 
	 * @param message
	 *            the message
	 */
	public static void setStatusMessage(String message) {
		if(getStatusLine() != null) {
			getStatusLine().setMessage(message);
		}
	}
}
