/*--------------------------------------------------------------------------+
$Id$
|                                                                          |
| Copyright 2016 fortiss GmbH                     |
|                                                                          |
| Licensed under the Apache License, Version 2.0 (the "License");          |
| you may not use this file except in compliance with the License.         |
| You may obtain a copy of the License at                                  |
|                                                                          |
|    http://www.apache.org/licenses/LICENSE-2.0                            |
|                                                                          |
| Unless required by applicable law or agreed to in writing, software      |
| distributed under the License is distributed on an "AS IS" BASIS,        |
| WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. |
| See the License for the specific language governing permissions and      |
| limitations under the License.                                           |
+--------------------------------------------------------------------------*/
package org.fortiss.tooling.base.annotation.valueprovider;

import org.fortiss.tooling.base.annotation.AnnotationEntry;
import org.fortiss.tooling.base.model.element.IAnnotatedSpecification;

/**
 * Container class to uniquely specify an {@link IAnnotatedSpecification} including its instanceKey
 * of multi-valued {@link IAnnotatedSpecification}s.
 * 
 * @author diewald
 * @author $Author$
 * @version $Rev$
 * @ConQAT.Rating GREEN Hash: 118C3ABB1846B192AE2DFD73E878ED05
 */
public class AnnotationInstSpec<T extends IAnnotatedSpecification> {
	/**
	 * {@link AnnotationEntry} from which a particular {@link IAnnotatedSpecification} is to be
	 * displayed in the column represented by this {@link AnnotationInstSpec}.
	 */
	private AnnotationEntry entry;

	/**
	 * {@link IAnnotatedSpecification} from {@code entry} to be displayed in the column
	 * represented by this {@link AnnotationInstSpec}.
	 */
	private Class<T> annotatedSpecificationClass;

	/**
	 * {@link IAnnotatedSpecification} from {@code entry} to be displayed in the column
	 * represented by this {@link AnnotationInstSpec}.
	 */
	private IAnnotatedSpecification annotatedSpecification;

	/**
	 * Instance key identifying the particular instance of an {@link IAnnotatedSpecification} from
	 * {@code entry} to be displayed in the column represented by this {@link AnnotationInstSpec}.
	 */
	private String instanceKey;

	/** Constructor. */
	public AnnotationInstSpec(AnnotationEntry entry, Class<T> annotatedSpecificationClass,
			T annotatedSpecification, String instanceKey) {
		this.entry = entry;
		this.annotatedSpecificationClass = annotatedSpecificationClass;
		this.annotatedSpecification = annotatedSpecification;
		this.instanceKey = instanceKey;
	}

	/**
	 * Returns the {@link AnnotationEntry} from which a particular {@link IAnnotatedSpecification}
	 * is to be displayed in the column represented by this {@link AnnotationInstSpec}.
	 */
	public AnnotationEntry getEntry() {
		return entry;
	}

	/**
	 * Returns the {@link IAnnotatedSpecification} from {@code entry} to be displayed in the
	 * column represented by this {@link AnnotationInstSpec}.
	 */
	public Class<T> getAnnotatedSpecificationType() {
		return annotatedSpecificationClass;
	}

	/**
	 * Returns the {@link IAnnotatedSpecification} from {@code entry} to be displayed in the
	 * column represented by this {@link AnnotationInstSpec}.
	 */
	public IAnnotatedSpecification getAnnotatedSpecification() {
		return annotatedSpecification;
	}

	/**
	 * Returns the instance key identifying the particular instance of an
	 * {@link IAnnotatedSpecification} from {@code entry} to be displayed in the column
	 * represented by this {@link AnnotationInstSpec}.
	 */
	public String getInstanceKey() {
		return instanceKey;
	}

	/**
	 * <p>
	 * The hashcode of the {@link AnnotationInstSpec} is ONLY based on the annotation type and the
	 * instance key to represent one particular annotation instance type. Nevertheless, the
	 * {@link AnnotationInstSpec} also carries references to the {@link AnnotationEntry} and the
	 * {@link IAnnotatedSpecification} instances to allow a backtracking to the originating
	 * elements.
	 * 
	 * {@inheritDoc}
	 */
	@Override
	public int hashCode() {
		return annotatedSpecificationClass.hashCode() +
				(instanceKey != null ? instanceKey.hashCode() : 0);
	}

	/** {@inheritDoc} */
	@Override
	public boolean equals(Object other) {
		if(other instanceof AnnotationInstSpec) {
			return this.hashCode() == other.hashCode();
		}
		return super.equals(other);
	}
}
