/*--------------------------------------------------------------------------+
$Id$
|                                                                          |
| Copyright 2013 fortiss GmbH                     |
|                                                                          |
| Licensed under the Apache License, Version 2.0 (the "License");          |
| you may not use this file except in compliance with the License.         |
| You may obtain a copy of the License at                                  |
|                                                                          |
|    http://www.apache.org/licenses/LICENSE-2.0                            |
|                                                                          |
| Unless required by applicable law or agreed to in writing, software      |
| distributed under the License is distributed on an "AS IS" BASIS,        |
| WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. |
| See the License for the specific language governing permissions and      |
| limitations under the License.                                           |
+--------------------------------------------------------------------------*/
package org.fortiss.tooling.base.compose;

import org.fortiss.tooling.base.dnd.ConnectionDragContext;
import org.fortiss.tooling.base.model.base.EntryConnectorBase;
import org.fortiss.tooling.base.model.element.IConnector;
import org.fortiss.tooling.base.model.element.IHierarchicElement;
import org.fortiss.tooling.kernel.extension.data.IConnectionCompositionContext;
import org.fortiss.tooling.kernel.extension.data.ITopLevelElement;
import org.fortiss.tooling.kernel.service.IPersistencyService;

/**
 * Compositor base class for connections between hierarchical elements and connectors.
 * 
 * @author igna
 * @author $Author$
 * @version $Rev$
 * @ConQAT.Rating GREEN Hash: 5E36AC9F62D43E2C7AAE0C60B0CF591E
 */
public abstract class HierarchicElementConnectorConnectionCompositorBase<HE extends IHierarchicElement, S extends IHierarchicElement, T extends IConnector>
		extends ConnectionCompositorBase<HE, S, T> {

	/** Creates the application specific source {@link IConnector} model element. */
	protected abstract IConnector createEntryConnector();

	/** Creates the application specific target {@link IConnector} model element. */
	protected abstract IConnector createExitConnector();

	/** {@inheritDoc} */
	@Override
	public boolean canConnect(S source, T target, HE parent, IConnectionCompositionContext context) {
		if(context instanceof ConnectionDragContext) {
			ConnectionDragContext dc = (ConnectionDragContext)context;
			if(dc.isTargetFreeConnector()) {
				return canConnectInternally(source, target);
			}
		}
		return true;
	}

	/** {@inheritDoc} */
	@Override
	protected boolean canConnectInternally(S source, T target) {
		return target.getIncoming().isEmpty();
	}

	/** {@inheritDoc} */
	@Override
	public boolean connect(S source, T target, HE parent, IConnectionCompositionContext context) {
		boolean isTargetEntry = target instanceof EntryConnectorBase;
		isTargetEntry = sameParent(source, target) ? isTargetEntry : !isTargetEntry;
		IConnector conn = isTargetEntry ? createEntryConnector() : createExitConnector();
		avoidDuplicateConnectorName(source, conn);

		createNewSourceDropContext(source, context, conn);

		ITopLevelElement topElement =
				IPersistencyService.getInstance().getTopLevelElementFor(parent);
		createConnection(conn, target, parent, topElement);
		return true;
	}
}
