/*--------------------------------------------------------------------------+
$Id$
|                                                                          |
| Copyright 2012 fortiss GmbH                     |
|                                                                          |
| Licensed under the Apache License, Version 2.0 (the "License");          |
| you may not use this file except in compliance with the License.         |
| You may obtain a copy of the License at                                  |
|                                                                          |
|    http://www.apache.org/licenses/LICENSE-2.0                            |
|                                                                          |
| Unless required by applicable law or agreed to in writing, software      |
| distributed under the License is distributed on an "AS IS" BASIS,        |
| WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. |
| See the License for the specific language governing permissions and      |
| limitations under the License.                                           |
+--------------------------------------------------------------------------*/
package org.fortiss.tooling.base.library;

import static org.eclipse.emf.ecore.util.EcoreUtil.copyAll;

import java.util.List;

import org.eclipse.emf.common.util.BasicEList;
import org.eclipse.emf.common.util.EList;
import org.eclipse.emf.ecore.EObject;
import org.fortiss.tooling.base.model.element.IConnection;
import org.fortiss.tooling.base.model.element.IConnector;
import org.fortiss.tooling.base.model.element.IHierarchicElement;
import org.fortiss.tooling.base.model.element.IModelElement;
import org.fortiss.tooling.base.model.layout.ILayoutedModelElement;
import org.fortiss.tooling.kernel.extension.ILibraryElementHandler;
import org.fortiss.tooling.kernel.extension.data.ITopLevelElement;
import org.fortiss.tooling.kernel.model.IIdLabeled;
import org.fortiss.tooling.kernel.model.ILibrary;
import org.fortiss.tooling.kernel.model.ILibraryElement;
import org.fortiss.tooling.kernel.model.ILibraryElementReference;
import org.fortiss.tooling.kernel.model.ILibraryPackage;
import org.fortiss.tooling.kernel.model.INamedElement;
import org.fortiss.tooling.kernel.service.ILibraryService;
import org.fortiss.tooling.kernel.service.IPersistencyService;

/**
 * Higher level {@link ILibraryService} for {@link IModelElement} objects.
 * 
 * @author ratiu
 * @author $Author$
 * @version $Rev$
 * @ConQAT.Rating GREEN Hash: 371BE0B8A8AA18CEAA9CB29AD3A14DEF
 */
public class ModelElementLibraryService implements ILibraryService {

	/** The instance of this service. */
	@Deprecated
	public static final ModelElementLibraryService INSTANCE = new ModelElementLibraryService();

	/** Returns the service instance. */
	public static ModelElementLibraryService getInstance() {
		return INSTANCE;
	}

	/** The private constructor. */
	private ModelElementLibraryService() {
		// do nothing
	}

	/** {@inheritDoc} */
	@Override
	public boolean isLibraryElementShadow(EObject anObject) {
		return ILibraryService.getInstance().isLibraryElementShadow(anObject);
	}

	/** {@inheritDoc} */
	@Override
	public boolean isDirty(ILibraryElementReference libRef) {
		return ILibraryService.getInstance().isDirty(libRef);
	}

	/** {@inheritDoc} */
	@Override
	public void setDirty(ILibraryElementReference libRef, boolean flag) {
		ILibraryService.getInstance().setDirty(libRef, flag);
	}

	/** {@inheritDoc} */
	@Override
	public ILibraryElement findLibraryElementByURI(String uri) {
		return ILibraryService.getInstance().findLibraryElementByURI(uri);
	}

	/** {@inheritDoc} */
	@Override
	public List<ILibraryElement> getLibraryElementsFromAllWorkspaceLibraries() {
		return ILibraryService.getInstance().getLibraryElementsFromAllWorkspaceLibraries();
	}

	/** {@inheritDoc} */
	@Override
	public List<ILibrary> getLibrariesFromWorkspace() {
		return ILibraryService.getInstance().getLibrariesFromWorkspace();
	}

	/** {@inheritDoc} */
	@Override
	public List<ILibraryPackage> getAllLibraryPackages(ILibrary lib) {
		return ILibraryService.getInstance().getAllLibraryPackages(lib);
	}

	/** {@inheritDoc} */
	@Override
	public void ensureWrappedElementIsUpToDate(ILibraryElementReference ref) {
		ILibraryService.getInstance().ensureWrappedElementIsUpToDate(ref);
	}

	/** {@inheritDoc} */
	@Override
	public void ensureChildrenLibraryReferenceAreUpToDate(EObject context) {
		ILibraryService.getInstance().ensureChildrenLibraryReferenceAreUpToDate(context);
	}

	/** {@inheritDoc} */
	@Override
	public void addElementToLibrary(ILibraryPackage pack, EObject obj) {
		ILibraryService.getInstance().addElementToLibrary(pack, obj);
	}

	/**
	 * Converts a {@link ILibraryElementReference} into a {@link IHierarchicElement} inside command
	 * stack.
	 */
	public void convertLibraryElementRefToHierarchicalElement(
			final ILibraryElementReference elementRef) {

		final ITopLevelElement topLevel =
				IPersistencyService.getInstance().getTopLevelElementFor(elementRef);
		topLevel.runAsCommand(new Runnable() {
			@Override
			public void run() {
				doConvertLibraryElementRefToHierarchicalElement(elementRef);
			}
		});
	}

	/** Converts a {@link ILibraryElementReference} into a {@link IHierarchicElement}. */
	public void doConvertLibraryElementRefToHierarchicalElement(
			final ILibraryElementReference elementRef) {
		IHierarchicElement wrapped = (IHierarchicElement)elementRef.getLibraryElementShadow();
		IHierarchicElement container = (IHierarchicElement)elementRef.eContainer();
		container.getContainedElements().remove(elementRef);

		// preserve the ID of the reference
		((IIdLabeled)wrapped).setId(((IIdLabeled)elementRef).getId());

		// copy all connectors of the reference to the wrapped component
		EList<IConnector> wrappedConnectorsList = new BasicEList<IConnector>();
		wrappedConnectorsList.addAll(wrapped.getConnectors());
		wrapped.getConnectors().clear();
		EList<IConnector> elementRefConnectorsList = new BasicEList<IConnector>();
		elementRefConnectorsList.addAll(((IHierarchicElement)elementRef).getConnectors());
		for(IConnector elemRefConnector : elementRefConnectorsList) {
			wrapped.getConnectors().add(elemRefConnector);
			String elementRefConnectorName = ((INamedElement)elemRefConnector).getName();

			// for each connector of the element reference add the inner connections from
			// the wrapped connector
			for(IConnector wrappedConnector : wrappedConnectorsList) {
				String currentWrappedConnectorName = ((INamedElement)wrappedConnector).getName();

				if(currentWrappedConnectorName.equals(elementRefConnectorName)) {

					// preserve the IDs of the reference connectors
					((IIdLabeled)wrappedConnector).setId(((IIdLabeled)elemRefConnector).getId());

					// copy incoming connections
					EList<IConnection> wrappedIncomingConnectionsList =
							new BasicEList<IConnection>();
					wrappedIncomingConnectionsList.addAll(wrappedConnector.getIncoming());
					for(IConnection connection : wrappedIncomingConnectionsList) {
						elemRefConnector.getIncoming().add(connection);
					}

					// copy outgoing connections
					EList<IConnection> wrappedOutgoingConnectionsList =
							new BasicEList<IConnection>();
					wrappedOutgoingConnectionsList.addAll(wrappedConnector.getOutgoing());
					for(IConnection connection : wrappedOutgoingConnectionsList) {
						elemRefConnector.getOutgoing().add(connection);
					}
				}
			}
		}

		copyAllLayoutData((ILayoutedModelElement)elementRef, (ILayoutedModelElement)wrapped);

		container.getContainedElements().add(wrapped);
	}

	/** Copies the layout data from source to target. */
	private static void
			copyAllLayoutData(ILayoutedModelElement source, ILayoutedModelElement target) {
		target.getLayoutData().clear();
		target.getLayoutData().addAll(copyAll(source.getLayoutData()));
	}

	/** {@inheritDoc} */
	@Override
	public void registerLibraryElementHandler(ILibraryElementHandler<EObject> handler,
			Class<?> modelElementClass) {
		ILibraryService.getInstance().registerLibraryElementHandler(handler, modelElementClass);
	}
}
