/*--------------------------------------------------------------------------+
$Id$
|                                                                          |
| Copyright 2013 fortiss GmbH                     |
|                                                                          |
| Licensed under the Apache License, Version 2.0 (the "License");          |
| you may not use this file except in compliance with the License.         |
| You may obtain a copy of the License at                                  |
|                                                                          |
|    http://www.apache.org/licenses/LICENSE-2.0                            |
|                                                                          |
| Unless required by applicable law or agreed to in writing, software      |
| distributed under the License is distributed on an "AS IS" BASIS,        |
| WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. |
| See the License for the specific language governing permissions and      |
| limitations under the License.                                           |
+--------------------------------------------------------------------------*/
package org.fortiss.tooling.base.migration;

import static org.fortiss.tooling.kernel.utils.UniqueIDUtils.fixMissingIDs;
import static org.fortiss.tooling.kernel.utils.UniqueIDUtils.hasMissingIDs;

import java.util.Map;

import org.eclipse.emf.ecore.EObject;
import org.eclipse.emf.ecore.xml.type.AnyType;
import org.fortiss.tooling.kernel.extension.IMigrationProvider;
import org.fortiss.tooling.kernel.extension.data.ITopLevelElement;

/**
 * {@link IDMigrationProvider} that - if required - adds missing IDs to a model.
 * 
 * @author Shaka
 * @author $Author$
 * @version $Rev$
 * @ConQAT.Rating GREEN Hash: A2192D0650CC14886FC95D45C8683847
 */
public class IDMigrationProvider implements IMigrationProvider {

	/** {@inheritDoc} */
	@Override
	public boolean needMigration(ITopLevelElement modelElement,
			Map<EObject, AnyType> unknownFeatures) {
		// if the id of model element is 0
		if(modelElement != null) {
			EObject rootElement = modelElement.getRootModelElement();
			return (rootElement != null) && hasMissingIDs(rootElement);
		}
		return false;
	}

	/** {@inheritDoc} */
	@Override
	public void migrate(ITopLevelElement modelElement, Map<EObject, AnyType> unknownFeatures) {
		fixMissingIDs(modelElement);
	}
}
