/*--------------------------------------------------------------------------+
$Id$
|                                                                          |
| Copyright 2011 fortiss GmbH                     |
|                                                                          |
| Licensed under the Apache License, Version 2.0 (the "License");          |
| you may not use this file except in compliance with the License.         |
| You may obtain a copy of the License at                                  |
|                                                                          |
|    http://www.apache.org/licenses/LICENSE-2.0                            |
|                                                                          |
| Unless required by applicable law or agreed to in writing, software      |
| distributed under the License is distributed on an "AS IS" BASIS,        |
| WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. |
| See the License for the specific language governing permissions and      |
| limitations under the License.                                           |
+--------------------------------------------------------------------------*/
package org.fortiss.tooling.base.utils;

import java.util.ArrayList;
import java.util.Collection;
import java.util.List;

import org.fortiss.tooling.base.model.element.IHierarchicElement;
import org.fortiss.tooling.base.model.element.IHierarchicElementContainer;
import org.fortiss.tooling.base.model.element.IModelElement;
import org.fortiss.tooling.base.model.element.IModelElementReference;
import org.fortiss.tooling.base.model.element.IModelElementSpecification;

/**
 * Utility class for model elements.
 * 
 * @author trachtenherz
 * @author mou
 * @author hoelzl
 * @author $Author$
 * @version $Rev$
 * @ConQAT.Rating GREEN Hash: F45F9E3D3EF1DDADA4CEE5727A641020
 */
public class BaseModelElementUtils {

	/**
	 * Return the index of the given {@link IHierarchicElement} in its parent
	 * {@link IHierarchicElementContainer}.
	 * 
	 * @param element
	 *            the hierarchic element
	 * 
	 * @return Index of the given {@link IHierarchicElement} in its parent
	 *         {@link IHierarchicElementContainer}.
	 */
	public static int getIndex(IHierarchicElement element) {
		IHierarchicElementContainer container = element.getContainer();
		if(container != null) {
			return container.getContainedElements().indexOf(element);
		}
		return -1;
	}

	/**
	 * Removes {@link IModelElementSpecification}s of a {@link IModelElement} that represent a
	 * {@link IModelElementReference}s to another model element.
	 * 
	 * @param modelElement
	 *            the {@link IModelElement} of which to remove the
	 *            {@link IModelElementSpecification}s
	 *            representing {@link IModelElementReference}s.
	 * 
	 * @return Whether the {@link IModelElementSpecification}s representing
	 *         {@link IModelElementReference} have been removed, i.e. if the model has been
	 *         modified.
	 */
	public static boolean removeModelElementReferenceSpecifications(IModelElement modelElement) {
		List<IModelElementSpecification> modelElementReferenceSpecifications =
				findModelElementReferenceSpecifications((modelElement).getSpecifications());

		boolean modelElementReferenceSpecificationsRemoved =
				!modelElementReferenceSpecifications.isEmpty();

		modelElement.getSpecifications().removeAll(modelElementReferenceSpecifications);

		return modelElementReferenceSpecificationsRemoved;
	}

	/**
	 * Finds all {@link IModelElementSpecification}s of a {@link IModelElement} that represent a
	 * {@link IModelElementReference}s to another model element.
	 */
	private static List<IModelElementSpecification> findModelElementReferenceSpecifications(
			Collection<IModelElementSpecification> specifications) {
		List<IModelElementSpecification> result = new ArrayList<IModelElementSpecification>();
		for(IModelElementSpecification specification : specifications) {
			if(specification instanceof IModelElementReference)
				result.add(specification);
		}
		return result;
	}
}
