/*--------------------------------------------------------------------------+
$Id$
|                                                                          |
| Copyright 2016 fortiss GmbH                     |
|                                                                          |
| Licensed under the Apache License, Version 2.0 (the "License");          |
| you may not use this file except in compliance with the License.         |
| You may obtain a copy of the License at                                  |
|                                                                          |
|    http://www.apache.org/licenses/LICENSE-2.0                            |
|                                                                          |
| Unless required by applicable law or agreed to in writing, software      |
| distributed under the License is distributed on an "AS IS" BASIS,        |
| WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. |
| See the License for the specific language governing permissions and      |
| limitations under the License.                                           |
+--------------------------------------------------------------------------*/
package org.fortiss.tooling.base.utils;

import java.util.Collection;
import java.util.List;

import org.fortiss.tooling.base.model.visualization.Axis;
import org.fortiss.tooling.base.model.visualization.DataPoint;
import org.fortiss.tooling.base.model.visualization.DataSet;
import org.fortiss.tooling.base.model.visualization.DataSetCollection;
import org.fortiss.tooling.base.model.visualization.Dimension;
import org.fortiss.tooling.base.model.visualization.VisualizationFactory;
import org.fortiss.tooling.base.model.visualization.VisualizationPackage;

/**
 * Class containing model element factory methods for {@link VisualizationPackage}.
 * 
 * @author eder
 * @author $Author$
 * @version $Rev$
 * @ConQAT.Rating GREEN Hash: 69D5A322A9FB667640DD718BB2467BDF
 */
public class VisualizationModelElementFactory {
	/** Creates a visualization {@link Dimension}. */
	public static <T> Dimension<T> createDimension(String name) {
		Dimension<T> dimension = VisualizationFactory.eINSTANCE.createDimension();
		dimension.setName(name);
		return dimension;
	}

	/** Creates a visualization {@link Axis}. */
	public static <T> Axis<T> createAxis(String name) {
		Axis<T> axis = VisualizationFactory.eINSTANCE.createAxis();
		axis.setName(name);
		return axis;
	}

	/** Creates a visualization {@link DataPoint}. */
	public static <T> DataPoint<T> createDataPoint(T start, T end, Axis<T> axis, Dimension<T> dim) {
		DataPoint<T> dataPoint = VisualizationFactory.eINSTANCE.createDataPoint();
		dataPoint.setStart(start);
		dataPoint.setEnd(end);
		dataPoint.setAxis(axis);
		dataPoint.setDimension(dim);
		return dataPoint;
	}

	/** Creates a visualization {@link DataSet}. */
	public static DataSet createDataSet(List<DataPoint<?>> dataPoints) {
		DataSet dataSet = VisualizationFactory.eINSTANCE.createDataSet();
		dataSet.getPoints().addAll(dataPoints);
		return dataSet;
	}

	/** Creates a visualization {@link DataSetCollection}. */
	@SuppressWarnings("unchecked")
	public static DataSetCollection createDataSetCollection(List<DataSet> dataSets,
			List<Axis<?>> axis, List<Dimension<?>> dims) {
		DataSetCollection dataSetCollection =
				VisualizationFactory.eINSTANCE.createDataSetCollection();
		dataSetCollection.getSets().addAll(dataSets);
		dataSetCollection.getAxes().addAll((Collection<? extends Axis<Object>>)axis);
		dataSetCollection.getDimensions().addAll((Collection<? extends Dimension<Object>>)dims);
		return dataSetCollection;
	}

	/** Creates an empty visualization {@link DataSetCollection}. */
	public static DataSetCollection createDataSetCollection() {
		return VisualizationFactory.eINSTANCE.createDataSetCollection();
	}

	/** Creates an empty visualization {@link DataSet}. */
	public static DataSet createDataSet() {
		return VisualizationFactory.eINSTANCE.createDataSet();
	}
}
