/*--------------------------------------------------------------------------+
$Id$
|                                                                          |
| Copyright 2016 fortiss GmbH                     |
|                                                                          |
| Licensed under the Apache License, Version 2.0 (the "License");          |
| you may not use this file except in compliance with the License.         |
| You may obtain a copy of the License at                                  |
|                                                                          |
|    http://www.apache.org/licenses/LICENSE-2.0                            |
|                                                                          |
| Unless required by applicable law or agreed to in writing, software      |
| distributed under the License is distributed on an "AS IS" BASIS,        |
| WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. |
| See the License for the specific language governing permissions and      |
| limitations under the License.                                           |
+--------------------------------------------------------------------------*/
package org.fortiss.tooling.kernel.extension.data;

import org.fortiss.tooling.kernel.extension.ITutorialStep;

/**
 * Base class for steps of tutorials.
 * 
 * @author hoelzl
 * @author $Author$
 * @version $Rev$
 * @ConQAT.Rating GREEN Hash: 1EC519A990807608FE86A71EAE0A6A66
 */
public abstract class TutorialStepBase implements ITutorialStep {
	/** The title of the tutorial. */
	private final String title;

	/** The description of this tutorial step. */
	private final String url;

	/** The parent element of this step. */
	private TutorialCompositeStep parent;

	/** Constructor. */
	public TutorialStepBase(String title, String url) {
		this.title = title;
		this.url = url;
	}

	/** Constructor. */
	public TutorialStepBase(String title) {
		this(title, "");
	}

	/** {@inheritDoc} */
	@Override
	public final String getTitle() {
		return title;
	}

	/** {@inheritDoc} */
	@Override
	public final String getUrl() {
		return url;
	}

	/** Sets the parent. */
	/* package */void setParent(TutorialCompositeStep parent) {
		this.parent = parent;
	}

	/** {@inheritDoc} */
	@Override
	public TutorialCompositeStep getParent() {
		return parent;
	}
}
