/*--------------------------------------------------------------------------+
$Id$
|                                                                          |
| Copyright 2016 fortiss GmbH                     |
|                                                                          |
| Licensed under the Apache License, Version 2.0 (the "License");          |
| you may not use this file except in compliance with the License.         |
| You may obtain a copy of the License at                                  |
|                                                                          |
|    http://www.apache.org/licenses/LICENSE-2.0                            |
|                                                                          |
| Unless required by applicable law or agreed to in writing, software      |
| distributed under the License is distributed on an "AS IS" BASIS,        |
| WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. |
| See the License for the specific language governing permissions and      |
| limitations under the License.                                           |
+--------------------------------------------------------------------------*/
package org.fortiss.tooling.kernel.internal;

import static org.fortiss.tooling.kernel.ToolingKernel.printPhase;

import org.fortiss.tooling.kernel.internal.storage.eclipse.EclipseResourceStorageService;

/**
 * Implementation of the kernel initialization and startup.
 * 
 * @author hoelzl
 * @author $Author$
 * @version $Rev$
 * @ConQAT.Rating GREEN Hash: 2BE97CFD1998DD9F516A3320092DE061
 */
public final class ToolingKernelInternal {
	/** Initialize the kernel services. */
	public static void initializeKernel() {
		printPhase("Tooling Kernel initializing ...");
		CommandStackService.getInstance().initializeService();
		ConnectionCompositorService.getInstance().initializeService();
		ConstraintCheckerService.getInstance().initializeService();
		ConstraintService.getInstance().initializeService();
		ElementCompositorService.getInstance().initializeService();
		MigrationService.getInstance().initializeService();
		EclipseResourceStorageService.getInstance().initializeService();
		LibraryService.getInstance().initializeService();
		LoggingService.getInstance().initializeService();
		PersistencyService.getInstance().initializeService();
		PrototypeService.getInstance().initializeService();
		TransformationService.getInstance().initializeService();
		TutorialService.getInstance().initializeService();
		printPhase("Tooling Kernel initialized.");
	}

	/** Starts the kernel services. */
	public static void startKernel() {
		printPhase("Tooling Kernel starting ...");
		CommandStackService.getInstance().startService();
		ConnectionCompositorService.getInstance().startService();
		ConstraintCheckerService.getInstance().startService();
		ConstraintService.getInstance().startService();
		ElementCompositorService.getInstance().startService();
		MigrationService.getInstance().startService();
		EclipseResourceStorageService.getInstance().startService();
		LibraryService.getInstance().startService();
		LoggingService.getInstance().startService();
		PersistencyService.getInstance().startService();
		PrototypeService.getInstance().startService();
		TransformationService.getInstance().startService();
		printPhase("Tooling Kernel started.");
	}
}
