/*--------------------------------------------------------------------------+
$Id$
|                                                                          |
| Copyright 2012 fortiss GmbH                     |
|                                                                          |
| Licensed under the Apache License, Version 2.0 (the "License");          |
| you may not use this file except in compliance with the License.         |
| You may obtain a copy of the License at                                  |
|                                                                          |
|    http://www.apache.org/licenses/LICENSE-2.0                            |
|                                                                          |
| Unless required by applicable law or agreed to in writing, software      |
| distributed under the License is distributed on an "AS IS" BASIS,        |
| WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. |
| See the License for the specific language governing permissions and      |
| limitations under the License.                                           |
+--------------------------------------------------------------------------*/
package org.fortiss.tooling.kernel.service;

import java.util.List;

import org.eclipse.emf.ecore.EObject;
import org.fortiss.tooling.kernel.extension.ILibraryElementHandler;
import org.fortiss.tooling.kernel.internal.LibraryService;
import org.fortiss.tooling.kernel.model.ILibrary;
import org.fortiss.tooling.kernel.model.ILibraryElement;
import org.fortiss.tooling.kernel.model.ILibraryElementReference;
import org.fortiss.tooling.kernel.model.ILibraryPackage;

/**
 * The library service provides high level access to the library.
 * 
 * @author ratiu
 * @author $Author$
 * @version $Rev$
 * @ConQAT.Rating GREEN Hash: D15F7C25F2EF844CE1A0976D07EA757A
 */
public interface ILibraryService {
	/** Returns the service instance. */
	public static ILibraryService getInstance() {
		return LibraryService.getInstance();
	}

	/**
	 * Returns true if the parameter is a shadow of a library element.
	 * A shadow is a temporary copy of an element, contained inside an
	 * {@link ILibraryElementReference}.
	 */
	boolean isLibraryElementShadow(EObject anObject);

	/**
	 * Returns true if the library reference is dirty. A library reference is dirty when the
	 * shadowed library element from inside is inconsistent with the library.
	 */
	boolean isDirty(ILibraryElementReference libRef);

	/** Sets the dirty flag for a library reference. */
	void setDirty(ILibraryElementReference libRef, boolean flag);

	/** Finds a {@link ILibraryElement} in the library. */
	ILibraryElement findLibraryElementByURI(String uri);

	/** Returns the list of {@link ILibraryElement} from all libraries loaded in the workspace. */
	List<ILibraryElement> getLibraryElementsFromAllWorkspaceLibraries();

	/** Returns the list of {@link ILibrary} objects loaded in the workspace. */
	List<ILibrary> getLibrariesFromWorkspace();

	/** Returns all {@link ILibraryPackage} objects from library. */
	List<ILibraryPackage> getAllLibraryPackages(ILibrary lib);

	/** Ensures that the wrapped model element behind this reference is up to date. */
	void ensureWrappedElementIsUpToDate(final ILibraryElementReference ref);

	/** Ensures that all children objects that reference library elements are up to date. */
	void ensureChildrenLibraryReferenceAreUpToDate(final EObject context);

	/** Adds an element to the library in a given library package. */
	void addElementToLibrary(final ILibraryPackage pack, final EObject obj);

	/** Registers the given handler with the service. */
	void registerLibraryElementHandler(ILibraryElementHandler<EObject> handler,
			Class<?> modelElementClass);
}
