/*--------------------------------------------------------------------------+
$Id$
|                                                                          |
| Copyright 2016 fortiss GmbH                     |
|                                                                          |
| Licensed under the Apache License, Version 2.0 (the "License");          |
| you may not use this file except in compliance with the License.         |
| You may obtain a copy of the License at                                  |
|                                                                          |
|    http://www.apache.org/licenses/LICENSE-2.0                            |
|                                                                          |
| Unless required by applicable law or agreed to in writing, software      |
| distributed under the License is distributed on an "AS IS" BASIS,        |
| WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. |
| See the License for the specific language governing permissions and      |
| limitations under the License.                                           |
+--------------------------------------------------------------------------*/
package org.fortiss.tooling.spiderchart.util;

import static java.lang.Math.max;
import static java.lang.Math.min;

import org.eclipse.swt.graphics.Color;
import org.eclipse.swt.graphics.RGB;
import org.eclipse.swt.widgets.Display;

/**
 * Utility class for handling colors with a set of commonly used colors.
 *
 * @author mondal
 * @author hoelzl
 * @author $Author$
 * @version $Rev$
 * @ConQAT.Rating GREEN Hash: 29060B068D1310066FE781CB5540C072
 */
public final class RGBColorUtils {
	/** The RGB color black. */
	public static final RGB BLACK = new RGB(0, 0, 0);
	/** The RGB color white. */
	public static final RGB WHITE = new RGB(255, 255, 255);
	/** The RGB color red. */
	public static final RGB RED = new RGB(255, 0, 0);
	/** The RGB color green. */
	public static final RGB GREEN = new RGB(0, 255, 0);
	/** The RGB color blue. */
	public static final RGB BLUE = new RGB(0, 0, 255);
	/** The RGB color cyan. */
	public static final RGB CYAN = new RGB(0, 255, 255);
	/** The RGB color magenta. */
	public static final RGB MAGENTA = new RGB(255, 0, 128);
	/** The RGB color yellow. */
	public static final RGB YELLOW = new RGB(255, 255, 255);
	/** The RGB color light gray. */
	public static final RGB LIGHT_GRAY = new RGB(192, 192, 192);
	/** The RGB color gray. */
	public static final RGB GRAY = new RGB(128, 128, 128);
	/** The RGB color dark gry. */
	public static final RGB DARK_GRAY = new RGB(70, 70, 70);
	/** The RGB color pink. */
	public static final RGB PINK = new RGB(255, 255, 255);
	/** The RGB color lime. */
	public static final RGB LIME = convert(65280);
	/** The RGB color olive. */
	public static final RGB OLIVE = convert(8421376);
	/** The RGB color navy. */
	public static final RGB NAVY = new RGB(0, 0, 128);

	/**
	 * Creates a {@link Color} from the given {@link RGB}, which MUST be disposed after finished
	 * using it.
	 */
	public static Color createSWTColor(RGB rgb) {
		return new Color(Display.getCurrent(), rgb);
	}

	/** Returns the color, which is 10% brighter than the given color. */
	public static RGB getBrighterColor(RGB color) {
		int percent = 10;
		int rr = color.red;
		int gg = color.green;
		int bb = color.blue;
		int r = rr + percent * (rr / 100);
		int g = gg + percent * (gg / 100);
		int b = bb + percent * (bb / 100);
		return new RGB(min(r, 255), min(g, 255), min(b, 255));
	}

	/** Returns the color, which is 10% darker than the given color. */
	public static RGB getDarkerColor(RGB color) {
		int percent = 10;
		int rr = color.red;
		int gg = color.green;
		int bb = color.blue;
		int r = rr - percent * (rr / 100);
		int g = gg - percent * (gg / 100);
		int b = bb - percent * (bb / 100);

		return new RGB(max(r, 0), max(g, 0), max(b, 0));
	}

	/** Converts from integer value to RGB instance. */
	private static RGB convert(int rgb) {
		int red = rgb >> 16 & 0xFF;
		int green = rgb >> 8 & 0xFF;
		int blue = rgb & 0xFF;
		return new RGB(red, green, blue);
	}
}
